/***************************************************************************
                          adm_encmjpeg.h  -  description
                             -------------------
    begin                : Tue Jul 23 2002
    copyright            : (C) 2002 by mean
    email                : fixounet@free.fr
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef __ADM_encoder_mjpegP__
#define __ADM_encoder_mjpegP__

typedef struct MJPEGConfig
{

  uint32_t qual;
  uint32_t swapped;
} MJPEGConfig;

#endif
